@@ -12,11 +12,11 @@ class Access:
     def http(self):
         self.https.off()
         self.set_port('http', self.config.service_type_http, self.config.port_http)
-        urls = self.insider.service_urls(self.config.service_name)
-        self.trusted.trusted(urls.domain_port)
+        info = self.insider.service_info(self.config.service_name)
+        self.trusted.trusted(info.external_host, info.external_port)
 
     def https(self):
         self.https.on()
         self.set_port('https', self.config.service_type_https, self.config.port_https)
-        urls = self.insider.service_urls(self.config.service_name)
-        self.trusted.trusted(urls.domain_port)
+        info = self.insider.service_info(self.config.service_name)
+        self.trusted.trusted(info.external_host, info.external_port)
